options nocenter validvarname=any;

*---Read in space-delimited ascii file;

data new_data;


infile 'hhr1996_11th_12th_members.dat' lrecl=20 missover DSD DLM=' ' print;
input
  R0000100
  R5754800
  R5754900
  R5758700
  R5758800
;
array nvarlist _numeric_;


*---Recode missing values to SAS custom system missing. See SAS
      documentation for use of MISSING option in procedures, e.g. PROC FREQ;

do over nvarlist;
  if nvarlist = -1 then nvarlist = .R;  /* Refused */
  if nvarlist = -2 then nvarlist = .D;  /* Dont know */
  if nvarlist = -3 then nvarlist = .I;  /* Invalid missing */
  if nvarlist = -4 then nvarlist = .V;  /* Valid missing */
  if nvarlist = -5 then nvarlist = .N;  /* Non-interview */
end;

  label R0000100 = "ID# (1-12686) 79";
  label R5754800 = "AGE OF 11TH PERSON 96";
  label R5754900 = "HGHST GRD COMPLTD BY 11TH PERS 96";
  label R5758700 = "AGE OF 12TH PERSON 96";
  label R5758800 = "HGHST GRD COMPLTD BY 12TH PERS 96";

/*---------------------------------------------------------------------*
 *  Crosswalk for Reference number & Question name                     *
 *---------------------------------------------------------------------*
 * Uncomment and edit this RENAME statement to rename variables
 * for ease of use.  You may need to use  name literal strings
 * e.g.  'variable-name'n   to create valid SAS variable names, or 
 * alter variables similarly named across years.
 * This command does not guarantee uniqueness

 * See SAS documentation for use of name literals and use of the
 * VALIDVARNAME=ANY option.     
 *---------------------------------------------------------------------*/
  /* *start* */

* RENAME
  R0000100 = 'CASEID_1979'n
  R5754800 = 'HHI_FINAL_AGE.11_1996'n
  R5754900 = 'HHI_FINAL_GRADECODE.11_1996'n
  R5758700 = 'HHI_FINAL_AGE.12_1996'n
  R5758800 = 'HHI_FINAL_GRADECODE.12_1996'n
;
  /* *finish* */

run;

proc means data=new_data n mean min max;
run;


/*---------------------------------------------------------------------*
 *  FORMATTED TABULATIONS                                              *
 *---------------------------------------------------------------------*
 * You can uncomment and edit the PROC FORMAT and PROC FREQ statements 
 * provided below to obtain formatted tabulations. The tabulations 
 * should reflect codebook values.
 * 
 * Please edit the formats below reflect any renaming of the variables
 * you may have done in the first data step. 
 *---------------------------------------------------------------------*/

/*
proc format; 
value vx1f
  0='0'
  1-4='1 TO 4'
  5-9='5 TO 9'
  10-14='10 TO 14'
  15-19='15 TO 19'
  20-24='20 TO 24'
  25-29='25 TO 29'
  30-34='30 TO 34'
  35-39='35 TO 39'
  40-44='40 TO 44'
  45-49='45 TO 49'
  50-99999999='50 TO 99999999: 50+'
;
value vx2f
  0='0: NONE'
  93='93: PRE-KINDERGARTEN'
  94='94: KINDERGARTEN'
  1='1: 1ST GRADE'
  2='2: 2ND GRADE'
  3='3: 3RD GRADE'
  4='4: 4TH GRADE'
  5='5: 5TH GRADE'
  6='6: 6TH GRADE'
  7='7: 7TH GRADE'
  8='8: 8TH GRADE'
  9='9: 9TH GRADE'
  10='10: 10TH GRADE'
  11='11: 11TH GRADE'
  12='12: 12TH GRADE'
  13='13: 1ST YEAR COLLEGE'
  14='14: 2ND YEAR COLLEGE'
  15='15: 3RD YEAR COLLEGE'
  16='16: 4TH YEAR COLLEGE'
  17='17: 5TH YEAR COLLEGE'
  18='18: 6TH YEAR COLLEGE'
  19='19: 7TH YEAR COLLEGE'
  20='20: 8TH YEAR COLLEGE'
  95='95: UNGRADED'
;
value vx3f
  0='0'
  1-4='1 TO 4'
  5-9='5 TO 9'
  10-14='10 TO 14'
  15-19='15 TO 19'
  20-24='20 TO 24'
  25-29='25 TO 29'
  30-34='30 TO 34'
  35-39='35 TO 39'
  40-44='40 TO 44'
  45-49='45 TO 49'
  50-99999999='50 TO 99999999: 50+'
;
value vx4f
  0='0: NONE'
  93='93: PRE-KINDERGARTEN'
  94='94: KINDERGARTEN'
  1='1: 1ST GRADE'
  2='2: 2ND GRADE'
  3='3: 3RD GRADE'
  4='4: 4TH GRADE'
  5='5: 5TH GRADE'
  6='6: 6TH GRADE'
  7='7: 7TH GRADE'
  8='8: 8TH GRADE'
  9='9: 9TH GRADE'
  10='10: 10TH GRADE'
  11='11: 11TH GRADE'
  12='12: 12TH GRADE'
  13='13: 1ST YEAR COLLEGE'
  14='14: 2ND YEAR COLLEGE'
  15='15: 3RD YEAR COLLEGE'
  16='16: 4TH YEAR COLLEGE'
  17='17: 5TH YEAR COLLEGE'
  18='18: 6TH YEAR COLLEGE'
  19='19: 7TH YEAR COLLEGE'
  20='20: 8TH YEAR COLLEGE'
  95='95: UNGRADED'
;
*/

/* 
 *--- Tabulations using reference number variables;
proc freq data=new_data;
tables _ALL_ /MISSING;
  format R5754800 vx1f.;
  format R5754900 vx2f.;
  format R5758700 vx3f.;
  format R5758800 vx4f.;
run;
*/

/*
*--- Tabulations using default named variables;
proc freq data=new_data;
tables _ALL_ /MISSING;
  format 'HHI_FINAL_AGE.11_1996'n vx1f.;
  format 'HHI_FINAL_GRADECODE.11_1996'n vx2f.;
  format 'HHI_FINAL_AGE.12_1996'n vx3f.;
  format 'HHI_FINAL_GRADECODE.12_1996'n vx4f.;
run;
*/